@@ -1,6 +1,7 @@
 """Logging"""
 import logging
-import sys
+
+from rich.logging import RichHandler
 
 
 # A log filter to filter out logs based on filter level
@@ -14,18 +15,16 @@ class LevelFilter(logging.Filter):
         return record.levelno < self.level
 
 
-log_formatter = logging.Formatter("%(name)s - %(levelname)s - %(message)s")
-
-# An handler for stderr
-stderr_handler = logging.StreamHandler(sys.stderr)
-
-# stderr_handler will log all logs
-stderr_handler.setLevel(logging.DEBUG)
-stderr_handler.setFormatter(log_formatter)
+# Rich Handler by default Initalize a Console with stderr stream for logs
+logging.basicConfig(
+    level="INFO",
+    format="%(name)s - %(message)s",
+    datefmt="[%X]",
+    handlers=[RichHandler()],
+)
 
 # Add the handlers to the root logger
 root_logger = logging.getLogger()
-root_logger.addHandler(stderr_handler)
 
 LOGGER = logging.getLogger(__package__)
 LOGGER.setLevel(logging.INFO)
