@@ -1,16 +1,17 @@
 """
 Resource definitions and helper utilities for tests.
 """
+import asyncio
 import os
 import shutil
+import sys
 import tempfile
 import unittest
+import pytest
 
-# Try python3 dependency, fall back if not available
-try:
-    from urllib2 import urlopen
-except ImportError:
-    from urllib.request import urlopen
+from urllib.request import urlopen
+
+from cve_bin_tool.async_utils import get_event_loop
 
 CURL_7_20_0_RPM = "curl-7.20.0-4.fc13.x86_64.rpm"
 CURL_7_20_0_URL = (
@@ -22,15 +23,15 @@ TMUX_DEB_NAME = "tmux_1.8-5_amd64.deb"
 TMUX_DEB = "https://mirrors.cat.pdx.edu/ubuntu/pool/main/t/tmux/" + TMUX_DEB_NAME
 
 
-class TempDirTest(unittest.TestCase):
+class TempDirTest:
     """ For tests that need a temp directory """
 
     @classmethod
-    def setUpClass(cls):
+    def setup_class(cls):
         cls.tempdir = tempfile.mkdtemp()
 
     @classmethod
-    def tearDownClass(cls):
+    def teardown_class(cls):
         shutil.rmtree(cls.tempdir)
 
 
@@ -48,3 +49,8 @@ def LONG_TESTS():
     if os.getenv("LONG_TESTS"):
         LONG_TESTS = int(os.getenv("LONG_TESTS"))
     return LONG_TESTS
+
+
+@pytest.fixture
+def event_loop():
+    yield get_event_loop()
